__title__ = "chromie"
__description__ = (
    "A simple utility CLI tool for packaging and maintaining chrome extensions."
)
__author__ = "Steffen Andersland"
__version__ = "0.2.3"
__license__ = "MIT"
__email__ = "steffen@andersland.dev"
